# llm_content_filter

`llm_content_filter` es un paquete simple de Python que permite filtrar texto inapropiado para grandes modelos de lenguaje (LLMs). 

## Instalación

Puedes instalar el paquete usando `pip`:

```bash
pip install llm_content_filter
